@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,6 +26,34 @@ class ClsClient(AbstractClient):
     _service = 'cls'
 
 
+    def ApplyConfigToMachineGroup(self, request):
+        """应用采集配置到指定机器组
+
+        :param request: Request instance for ApplyConfigToMachineGroup.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ApplyConfigToMachineGroupRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ApplyConfigToMachineGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ApplyConfigToMachineGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ApplyConfigToMachineGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateAlarm(self, request):
         """本接口用于创建告警策略。
 
@@ -82,6 +110,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateConfig(self, request):
+        """创建采集规则配置
+
+        :param request: Request instance for CreateConfig.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateConfigRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateExport(self, request):
         """本接口用于创建日志导出
 
@@ -138,6 +194,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateLogset(self, request):
+        """本接口用于创建日志集，返回新创建的日志集的 ID。
+
+        :param request: Request instance for CreateLogset.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateLogsetRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateLogsetResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateLogset", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateLogsetResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateMachineGroup(self, request):
         """创建机器组
 
@@ -166,6 +250,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateShipper(self, request):
+        """创建新的投递规则，客户如果使用此接口，需要自行处理CLS对指定bucket的写权限。
+
+        :param request: Request instance for CreateShipper.
+        :type request: :class:`tencentcloud.cls.v20201016.models.CreateShipperRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.CreateShipperResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateShipper", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateShipperResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateTopic(self, request):
         """本接口用于创建日志主题。
 
@@ -250,6 +362,62 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteConfig(self, request):
+        """删除采集规则配置
+
+        :param request: Request instance for DeleteConfig.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteConfigRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteConfigFromMachineGroup(self, request):
+        """删除应用到机器组的采集配置
+
+        :param request: Request instance for DeleteConfigFromMachineGroup.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteConfigFromMachineGroupRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteConfigFromMachineGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteConfigFromMachineGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteConfigFromMachineGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteExport(self, request):
         """本接口用于删除日志导出
 
@@ -306,6 +474,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteLogset(self, request):
+        """本接口用于删除日志集。
+
+        :param request: Request instance for DeleteLogset.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteLogsetRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteLogsetResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteLogset", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteLogsetResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteMachineGroup(self, request):
         """删除机器组
 
@@ -334,6 +530,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteShipper(self, request):
+        """删除投递规则
+
+        :param request: Request instance for DeleteShipper.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DeleteShipperRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DeleteShipperResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteShipper", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteShipperResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteTopic(self, request):
         """本接口用于删除日志主题。
 
@@ -418,6 +642,62 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeConfigMachineGroups(self, request):
+        """获取采集规则配置所绑定的机器组
+
+        :param request: Request instance for DescribeConfigMachineGroups.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeConfigMachineGroupsRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeConfigMachineGroupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeConfigMachineGroups", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeConfigMachineGroupsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeConfigs(self, request):
+        """获取采集规则配置
+
+        :param request: Request instance for DescribeConfigs.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeConfigsRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeConfigs", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeConfigsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeExports(self, request):
         """本接口用于获取日志导出列表
 
@@ -502,6 +782,62 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeLogsets(self, request):
+        """本接口用于获取日志集信息列表。
+
+        :param request: Request instance for DescribeLogsets.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeLogsetsRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeLogsetsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeLogsets", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeLogsetsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeMachineGroupConfigs(self, request):
+        """获取机器组绑定的采集规则配置
+
+        :param request: Request instance for DescribeMachineGroupConfigs.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeMachineGroupConfigsRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeMachineGroupConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeMachineGroupConfigs", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeMachineGroupConfigsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeMachineGroups(self, request):
         """获取机器组信息列表
 
@@ -586,6 +922,62 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeShipperTasks(self, request):
+        """获取投递任务列表
+
+        :param request: Request instance for DescribeShipperTasks.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeShipperTasksRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeShipperTasksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeShipperTasks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeShipperTasksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeShippers(self, request):
+        """获取投递规则信息列表
+
+        :param request: Request instance for DescribeShippers.
+        :type request: :class:`tencentcloud.cls.v20201016.models.DescribeShippersRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.DescribeShippersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeShippers", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeShippersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTopics(self, request):
         """本接口用于获取日志主题列表，支持分页
 
@@ -726,6 +1118,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyConfig(self, request):
+        """修改采集规则配置
+
+        :param request: Request instance for ModifyConfig.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ModifyConfigRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ModifyConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyIndex(self, request):
         """本接口用于修改索引配置
 
@@ -754,6 +1174,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyLogset(self, request):
+        """本接口用于修改日志集信息
+
+        :param request: Request instance for ModifyLogset.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ModifyLogsetRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ModifyLogsetResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyLogset", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyLogsetResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyMachineGroup(self, request):
         """修改机器组
 
@@ -782,6 +1230,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyShipper(self, request):
+        """修改现有的投递规则，客户如果使用此接口，需要自行处理CLS对指定bucket的写权限。
+
+        :param request: Request instance for ModifyShipper.
+        :type request: :class:`tencentcloud.cls.v20201016.models.ModifyShipperRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.ModifyShipperResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyShipper", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyShipperResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyTopic(self, request):
         """本接口用于修改日志主题。
 
@@ -810,6 +1286,34 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RetryShipperTask(self, request):
+        """重试失败的投递任务
+
+        :param request: Request instance for RetryShipperTask.
+        :type request: :class:`tencentcloud.cls.v20201016.models.RetryShipperTaskRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.RetryShipperTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RetryShipperTask", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RetryShipperTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SearchLog(self, request):
         """本接口用于搜索日志
 
