@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -53,6 +55,13 @@ class ActivateSubscribeRequest(AbstractModel):
             self.Objects._deserialize(params.get("Objects"))
         self.UniqSubnetId = params.get("UniqSubnetId")
         self.Vport = params.get("Vport")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ActivateSubscribeResponse(AbstractModel):
@@ -85,12 +94,23 @@ class CompleteMigrateJobRequest(AbstractModel):
         """
         :param JobId: 数据迁移任务ID
         :type JobId: str
+        :param CompleteMode: 完成任务的方式,仅支持旧版MySQL迁移任务。waitForSync-等待主从差距为0才停止,immediately-立即完成，不会等待主从差距一致。默认为waitForSync
+        :type CompleteMode: str
         """
         self.JobId = None
+        self.CompleteMode = None
 
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        self.CompleteMode = params.get("CompleteMode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CompleteMigrateJobResponse(AbstractModel):
@@ -133,6 +153,13 @@ class ConsistencyParams(AbstractModel):
         self.SelectRowsPerTable = params.get("SelectRowsPerTable")
         self.TablesSelectAll = params.get("TablesSelectAll")
         self.TablesSelectCount = params.get("TablesSelectCount")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateMigrateCheckJobRequest(AbstractModel):
@@ -150,6 +177,13 @@ class CreateMigrateCheckJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateMigrateCheckJobResponse(AbstractModel):
@@ -230,6 +264,13 @@ Schema:s1}]
             self.DstInfo = DstInfo()
             self.DstInfo._deserialize(params.get("DstInfo"))
         self.DatabaseInfo = params.get("DatabaseInfo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateMigrateJobResponse(AbstractModel):
@@ -293,6 +334,13 @@ class CreateSubscribeRequest(AbstractModel):
                 obj = TagItem()
                 obj._deserialize(item)
                 self.Tags.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateSubscribeResponse(AbstractModel):
@@ -332,6 +380,13 @@ class CreateSyncCheckJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateSyncCheckJobResponse(AbstractModel):
@@ -406,6 +461,13 @@ class CreateSyncJobRequest(AbstractModel):
             self.DstInfo = SyncInstanceInfo()
             self.DstInfo._deserialize(params.get("DstInfo"))
         self.DatabaseInfo = params.get("DatabaseInfo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateSyncJobResponse(AbstractModel):
@@ -444,6 +506,13 @@ class DeleteMigrateJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteMigrateJobResponse(AbstractModel):
@@ -478,6 +547,13 @@ class DeleteSyncJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DeleteSyncJobResponse(AbstractModel):
@@ -512,6 +588,13 @@ class DescribeAsyncRequestInfoRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.AsyncRequestId = params.get("AsyncRequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeAsyncRequestInfoResponse(AbstractModel):
@@ -554,6 +637,13 @@ class DescribeMigrateCheckJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeMigrateCheckJobResponse(AbstractModel):
@@ -628,6 +718,13 @@ class DescribeMigrateJobsRequest(AbstractModel):
         self.OrderSeq = params.get("OrderSeq")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeMigrateJobsResponse(AbstractModel):
@@ -711,6 +808,13 @@ class DescribeSubscribeConfRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.SubscribeId = params.get("SubscribeId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeSubscribeConfResponse(AbstractModel):
@@ -914,6 +1018,13 @@ class DescribeSubscribesRequest(AbstractModel):
                 obj._deserialize(item)
                 self.TagFilters.append(obj)
         self.SubscribeVersion = params.get("SubscribeVersion")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeSubscribesResponse(AbstractModel):
@@ -961,6 +1072,13 @@ class DescribeSyncCheckJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeSyncCheckJobResponse(AbstractModel):
@@ -1040,6 +1158,13 @@ class DescribeSyncJobsRequest(AbstractModel):
         self.OrderSeq = params.get("OrderSeq")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeSyncJobsResponse(AbstractModel):
@@ -1111,6 +1236,13 @@ class DstInfo(AbstractModel):
         self.ReadOnly = params.get("ReadOnly")
         self.User = params.get("User")
         self.Password = params.get("Password")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ErrorInfo(AbstractModel):
@@ -1132,6 +1264,13 @@ class ErrorInfo(AbstractModel):
     def _deserialize(self, params):
         self.ErrorLog = params.get("ErrorLog")
         self.HelpDoc = params.get("HelpDoc")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class IsolateSubscribeRequest(AbstractModel):
@@ -1149,6 +1288,13 @@ class IsolateSubscribeRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.SubscribeId = params.get("SubscribeId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class IsolateSubscribeResponse(AbstractModel):
@@ -1212,6 +1358,13 @@ class MigrateDetailInfo(AbstractModel):
                 obj = MigrateStepDetailInfo()
                 obj._deserialize(item)
                 self.StepInfo.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MigrateJobInfo(AbstractModel):
@@ -1302,6 +1455,13 @@ class MigrateJobInfo(AbstractModel):
                 obj = ErrorInfo()
                 obj._deserialize(item)
                 self.ErrorInfo.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MigrateOption(AbstractModel):
@@ -1364,6 +1524,13 @@ MySQL暂不支持额外参数设置。
         if params.get("ConsistencyParams") is not None:
             self.ConsistencyParams = ConsistencyParams()
             self.ConsistencyParams._deserialize(params.get("ConsistencyParams"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class MigrateStepDetailInfo(AbstractModel):
@@ -1398,6 +1565,13 @@ class MigrateStepDetailInfo(AbstractModel):
         self.StepId = params.get("StepId")
         self.Status = params.get("Status")
         self.StartTime = params.get("StartTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyMigrateJobRequest(AbstractModel):
@@ -1456,6 +1630,13 @@ class ModifyMigrateJobRequest(AbstractModel):
             self.DstInfo = DstInfo()
             self.DstInfo._deserialize(params.get("DstInfo"))
         self.DatabaseInfo = params.get("DatabaseInfo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyMigrateJobResponse(AbstractModel):
@@ -1494,6 +1675,13 @@ class ModifySubscribeAutoRenewFlagRequest(AbstractModel):
     def _deserialize(self, params):
         self.SubscribeId = params.get("SubscribeId")
         self.AutoRenewFlag = params.get("AutoRenewFlag")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifySubscribeAutoRenewFlagResponse(AbstractModel):
@@ -1532,6 +1720,13 @@ class ModifySubscribeConsumeTimeRequest(AbstractModel):
     def _deserialize(self, params):
         self.SubscribeId = params.get("SubscribeId")
         self.ConsumeStartTime = params.get("ConsumeStartTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifySubscribeConsumeTimeResponse(AbstractModel):
@@ -1570,6 +1765,13 @@ class ModifySubscribeNameRequest(AbstractModel):
     def _deserialize(self, params):
         self.SubscribeId = params.get("SubscribeId")
         self.SubscribeName = params.get("SubscribeName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifySubscribeNameResponse(AbstractModel):
@@ -1617,6 +1819,13 @@ class ModifySubscribeObjectsRequest(AbstractModel):
                 obj = SubscribeObject()
                 obj._deserialize(item)
                 self.Objects.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifySubscribeObjectsResponse(AbstractModel):
@@ -1667,6 +1876,13 @@ class ModifySubscribeVipVportRequest(AbstractModel):
         self.DstUniqSubnetId = params.get("DstUniqSubnetId")
         self.DstIp = params.get("DstIp")
         self.DstPort = params.get("DstPort")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifySubscribeVipVportResponse(AbstractModel):
@@ -1717,6 +1933,13 @@ class ModifySyncJobRequest(AbstractModel):
             self.SyncOption = SyncOption()
             self.SyncOption._deserialize(params.get("SyncOption"))
         self.DatabaseInfo = params.get("DatabaseInfo")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifySyncJobResponse(AbstractModel):
@@ -1751,6 +1974,13 @@ class OfflineIsolatedSubscribeRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.SubscribeId = params.get("SubscribeId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OfflineIsolatedSubscribeResponse(AbstractModel):
@@ -1785,6 +2015,13 @@ class ResetSubscribeRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.SubscribeId = params.get("SubscribeId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ResetSubscribeResponse(AbstractModel):
@@ -1880,6 +2117,13 @@ class SrcInfo(AbstractModel):
         self.Supplier = params.get("Supplier")
         self.CcnId = params.get("CcnId")
         self.EngineVersion = params.get("EngineVersion")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StartMigrateJobRequest(AbstractModel):
@@ -1897,6 +2141,13 @@ class StartMigrateJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StartMigrateJobResponse(AbstractModel):
@@ -1931,6 +2182,13 @@ class StartSyncJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StartSyncJobResponse(AbstractModel):
@@ -1965,6 +2223,13 @@ class StopMigrateJobRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.JobId = params.get("JobId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StopMigrateJobResponse(AbstractModel):
@@ -2099,6 +2364,13 @@ class SubscribeInfo(AbstractModel):
                 self.Tags.append(obj)
         self.AutoRenewFlag = params.get("AutoRenewFlag")
         self.SubscribeVersion = params.get("SubscribeVersion")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SubscribeObject(AbstractModel):
@@ -2127,6 +2399,13 @@ class SubscribeObject(AbstractModel):
         self.ObjectsType = params.get("ObjectsType")
         self.DatabaseName = params.get("DatabaseName")
         self.TableNames = params.get("TableNames")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SubscribeRegionConf(AbstractModel):
@@ -2165,6 +2444,13 @@ class SubscribeRegionConf(AbstractModel):
         self.Area = params.get("Area")
         self.IsDefaultRegion = params.get("IsDefaultRegion")
         self.Status = params.get("Status")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SwitchDrToMasterRequest(AbstractModel):
@@ -2188,6 +2474,13 @@ class SwitchDrToMasterRequest(AbstractModel):
             self.DstInfo = SyncInstanceInfo()
             self.DstInfo._deserialize(params.get("DstInfo"))
         self.DatabaseType = params.get("DatabaseType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SwitchDrToMasterResponse(AbstractModel):
@@ -2238,6 +2531,13 @@ class SyncCheckStepInfo(AbstractModel):
         self.StepName = params.get("StepName")
         self.StepCode = params.get("StepCode")
         self.StepMessage = params.get("StepMessage")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SyncDetailInfo(AbstractModel):
@@ -2284,6 +2584,13 @@ class SyncDetailInfo(AbstractModel):
                 obj = SyncStepDetailInfo()
                 obj._deserialize(item)
                 self.StepInfo.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SyncInstanceInfo(AbstractModel):
@@ -2305,6 +2612,13 @@ class SyncInstanceInfo(AbstractModel):
     def _deserialize(self, params):
         self.Region = params.get("Region")
         self.InstanceId = params.get("InstanceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SyncJobInfo(AbstractModel):
@@ -2386,6 +2700,13 @@ class SyncJobInfo(AbstractModel):
         self.CreateTime = params.get("CreateTime")
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SyncOption(AbstractModel):
@@ -2415,6 +2736,13 @@ class SyncOption(AbstractModel):
         self.RunMode = params.get("RunMode")
         self.SyncType = params.get("SyncType")
         self.ConsistencyType = params.get("ConsistencyType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class SyncStepDetailInfo(AbstractModel):
@@ -2444,6 +2772,13 @@ class SyncStepDetailInfo(AbstractModel):
         self.StepName = params.get("StepName")
         self.CanStop = params.get("CanStop")
         self.StepId = params.get("StepId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TagFilter(AbstractModel):
@@ -2465,6 +2800,13 @@ class TagFilter(AbstractModel):
     def _deserialize(self, params):
         self.TagKey = params.get("TagKey")
         self.TagValue = params.get("TagValue")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class TagItem(AbstractModel):
@@ -2486,4 +2828,11 @@ class TagItem(AbstractModel):
 
     def _deserialize(self, params):
         self.TagKey = params.get("TagKey")
-        self.TagValue = params.get("TagValue")
\ No newline at end of file
+        self.TagValue = params.get("TagValue")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
