@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,31 +13,34 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
 class Device(AbstractModel):
-    """Device结果
+    """用于表示业务用户对应的设备信息
 
     """
 
     def __init__(self):
         """
-        :param Ip: 发表消息设备IP
+        :param Ip: 该字段表示业务用户对应设备的IP地址，同时**支持IPv4和IPv6**地址的记录；需要与IpType参数配合使用。
         :type Ip: str
-        :param Mac: Mac地址
+        :param Mac: 该字段表示业务用户对应的MAC地址，以方便设备识别与管理；其格式与取值与标准MAC地址一致。
         :type Mac: str
-        :param TokenId: 设备指纹Token
+        :param TokenId: *内测中，敬请期待。*
         :type TokenId: str
-        :param DeviceId: 设备指纹ID
+        :param DeviceId: *内测中，敬请期待。*
         :type DeviceId: str
-        :param IMEI: 设备序列号
+        :param IMEI: 该字段表示业务用户对应设备的**IMEI码**（国际移动设备识别码），该识别码可用于识别每一部独立的手机等移动通信设备，方便设备识别与管理。<br>备注：格式为**15-17位纯数字**。
         :type IMEI: str
-        :param IDFA: IOS设备，Identifier For Advertising（广告标识符）
+        :param IDFA: **iOS设备专用**，该字段表示业务用户对应的**IDFA**(广告标识符),这是由苹果公司提供的用于追踪用户的广告标识符，由一串16进制的32位数字和字母组成。<br>
+备注：苹果公司自2021年iOS14更新后允许用户手动关闭或者开启IDFA，故此字符串标记有效性可能有所降低。
         :type IDFA: str
-        :param IDFV: IOS设备，IDFV - Identifier For Vendor（应用开发商标识符）
+        :param IDFV: **iOS设备专用**，该字段表示业务用户对应的**IDFV**(应用开发商标识符),这是由苹果公司提供的用于标注应用开发商的标识符，由一串16进制的32位数字和字母组成，可被用于唯一标识设备。
         :type IDFV: str
-        :param IpType: IP地址类型 0 代表ipv4 1 代表ipv6
+        :param IpType: 该字段表示记录的IP地址的类型，取值：**0**（代表IPv4地址）、**1**（代表IPv6地址）；需要与IpType参数配合使用。
         :type IpType: int
         """
         self.Ip = None
@@ -59,6 +62,13 @@ class Device(AbstractModel):
         self.IDFA = params.get("IDFA")
         self.IDFV = params.get("IDFV")
         self.IpType = params.get("IpType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageModerationRequest(AbstractModel):
@@ -68,21 +78,21 @@ class ImageModerationRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param BizType: 该字段用于标识业务场景。您可以在内容安全控制台创建对应的ID，配置不同的内容审核策略，通过接口调用，默认不填为0，后端使用默认策略。 -- 该字段暂未开放。
+        :param BizType: 该字段表示策略的具体编号，用于接口调度，在内容安全控制台中可配置。若不传入Biztype参数（留空），则代表采用默认的识别策略；传入则会在审核时根据业务场景采取不同的审核策略。<br>备注：Biztype仅为数字、字母与下划线的组合，长度为3-32个字符；不同Biztype关联不同的业务场景与识别能力策略，调用前请确认正确的Biztype。
         :type BizType: str
-        :param DataId: 数据ID，可以由英文字母、数字、下划线、-、@#组成，不超过64个字符
+        :param DataId: 该字段表示您为待检测对象分配的数据ID，传入后可方便您对文件进行标识和管理。<br>取值：由英文字母（大小写均可）、数字及四个特殊符号（_，-，@，#）组成，**长度不超过64个字符**。
         :type DataId: str
-        :param FileContent: 数据Base64编码，图片检测接口为图片文件内容，大小不能超过5M
+        :param FileContent: 该字段表示待检测图片文件内容的Base64编码，图片**大小不超过5MB**，建议**分辨率不低于256x256**，否则可能会影响识别效果。<br>备注： **该字段与FileUrl必须选择输入其中一个**。
         :type FileContent: str
-        :param FileUrl: 图片资源访问链接，__与FileContent参数必须二选一输入__
+        :param FileUrl: 该字段表示待检测图片文件的访问链接，图片支持PNG、JPG、JPEG、BMP、GIF、WEBP格式，**大小不超过5MB**，建议**分辨率不低于256x256**；图片下载时间限制为3秒，超过则会返回下载超时。<br>备注：**该字段与FileContent必须选择输入其中一个**。
         :type FileUrl: str
-        :param Interval: 截帧频率，GIF图/长图检测专用，默认值为0，表示只会检测GIF图/长图的第一帧
+        :param Interval: **GIF/长图检测专用**，用于表示GIF截帧频率（每隔多少张图片抽取一帧进行检测），长图则按照长边：短边取整计算要切割的总图数；默认值为0，此时只会检测GIF的第一帧或对长图不进行切分处理。<br>备注：Interval与MaxFrames参数需要组合使用。例如，Interval=3, MaxFrames=400，则代表在检测GIF/长图时，将每间隔2帧检测一次且最多检测400帧。
         :type Interval: int
-        :param MaxFrames: GIF图/长图检测专用，代表均匀最大截帧数量，默认值为1（即只取GIF第一张，或长图不做切分处理（可能会造成处理超时））。
+        :param MaxFrames: **GIF/长图检测专用**，用于标识最大截帧数量；默认值为1，此时只会检测输入GIF的第一帧或对长图不进行切分处理（可能会造成处理超时）。<br>备注：Interval与MaxFrames参数需要组合使用。例如，Interval=3, MaxFrames=400，则代表在检测GIF/长图时，将每间隔2帧检测一次且最多检测400帧。
         :type MaxFrames: int
-        :param User: 账号相关信息字段，填入后可识别违规风险账号。
+        :param User: 该字段表示待检测对象对应的用户相关信息，若填入则可甄别相应违规风险用户。
         :type User: :class:`tencentcloud.ims.v20201229.models.User`
-        :param Device: 设备相关信息字段，填入后可识别违规风险设备。
+        :param Device: 该字段表示待检测对象对应的设备相关信息，若填入则可甄别相应违规风险设备。
         :type Device: :class:`tencentcloud.ims.v20201229.models.Device`
         """
         self.BizType = None
@@ -108,6 +118,13 @@ class ImageModerationRequest(AbstractModel):
         if params.get("Device") is not None:
             self.Device = Device()
             self.Device._deserialize(params.get("Device"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageModerationResponse(AbstractModel):
@@ -117,39 +134,34 @@ class ImageModerationResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Suggestion: 建议您拿到判断结果后的执行操作。
-建议值，Block：建议屏蔽，Review：建议复审，Pass：建议通过
+        :param Suggestion: 该字段用于返回Label标签下的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
         :type Suggestion: str
-        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义图片。
-以及其他令人反感、不安全或不适宜的内容类型。
+        :param Label: 该字段用于返回检测结果（LabelResults）中所对应的**优先级最高的恶意标签**，表示模型推荐的审核结果，建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
         :type Label: str
-        :param SubLabel: 子标签名称，如色情--性行为；当未命中子标签时，返回空字符串；
+        :param SubLabel: 该字段用于返回检测结果所命中优先级最高的恶意标签下的子标签名称，如：*色情--性行为*；若未命中任何子标签则返回空字符串。
         :type SubLabel: str
-        :param Score: 机器判断当前分类的置信度，取值范围：0.00~100.00。分数越高，表示越有可能属于当前分类。
-（如：色情 99.99，则该样本属于色情的置信度非常高。）
+        :param Score: 该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容。
         :type Score: int
-        :param LabelResults: 智能模型的识别结果，包括涉黄、广告等令人反感、不安全或不适宜的内容类型识别结果。
+        :param LabelResults: 该字段用于返回分类模型命中的恶意标签的详细识别结果，包括涉黄、广告等令人反感、不安全或不适宜的内容类型识别结果。
 注意：此字段可能返回 null，表示取不到有效值。
         :type LabelResults: list of LabelResult
-        :param ObjectResults: 物体检测模型的审核结果，包括实体、广告台标/二维码等物体坐标信息与内容审核信息。
+        :param ObjectResults: 该字段用于返回物体检测模型的详细检测结果；包括：实体、广告台标、二维码等内容命中的标签名称、标签分数、坐标信息、场景识别结果、建议操作等内容审核信息；详细返回值信息可参阅对应的数据结构（ObjectResults）描述。
 注意：此字段可能返回 null，表示取不到有效值。
         :type ObjectResults: list of ObjectResult
-        :param OcrResults: OCR识别后的文本识别结果，包括文本所处图片的OCR坐标信息以及图片文本的识别结果。
+        :param OcrResults: 该字段用于返回OCR文本识别的详细检测结果；包括：文本坐标信息、文本识别结果、建议操作等内容审核信息；详细返回值信息可参阅对应的数据结构（OcrResults）描述。
 注意：此字段可能返回 null，表示取不到有效值。
         :type OcrResults: list of OcrResult
-        :param LibResults: 基于图片风险库识别的结果。
-风险库包括不安全黑库与正常白库的结果。
+        :param LibResults: 该字段用于返回基于图片风险库（风险黑库与正常白库）识别的结果,详细返回值信息可参阅对应的数据结构（LibResults）描述。<br>备注：图片风险库目前**暂不支持自定义库**。
 注意：此字段可能返回 null，表示取不到有效值。
         :type LibResults: list of LibResult
-        :param DataId: 请求参数中的DataId。
+        :param DataId: 该字段用于返回检测对象对应请求参数中的DataId。
         :type DataId: str
-        :param BizType: 您在入参时所填入的Biztype参数。 -- 该字段暂未开放。
+        :param BizType: 该字段用于返回检测对象对应请求参数中的BizType。
         :type BizType: str
-        :param Extra: 扩展字段，用于特定信息返回，不同客户/Biztype下返回信息不同。
-注意：此字段可能返回 null，表示取不到有效值。
+        :param Extra: 该字段用于返回根据您的需求配置的额外附加信息（Extra），如未配置则默认返回值为空。<br>备注：不同客户或Biztype下返回信息不同，如需配置该字段请提交工单咨询或联系售后专员处理。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Extra: str
-        :param FileMD5: 图片MD5值
+        :param FileMD5: 该字段用于返回检测对象对应的MD5校验值，以方便校验文件完整性。
         :type FileMD5: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -272,6 +284,13 @@ class ImageRecognitionRequest(AbstractModel):
         self.CustomUin = params.get("CustomUin")
         self.CustomSubAccountUin = params.get("CustomSubAccountUin")
         self.StreamId = params.get("StreamId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ImageRecognitionResponse(AbstractModel):
@@ -370,19 +389,19 @@ class ImageRecognitionResponse(AbstractModel):
 
 
 class LabelDetailItem(AbstractModel):
-    """分类模型命中子标签结果
+    """用于返回分类模型命中子标签的详细结果
 
     """
 
     def __init__(self):
         """
-        :param Id: 序号
+        :param Id: 该字段用于返回识别对象的ID以方便识别和区分。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Id: int
-        :param Name: 子标签名称
+        :param Name: 该字段用于返回识命中的子标签名称。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Name: str
-        :param Score: 子标签分数
+        :param Score: 该字段用于返回对应子标签命中的分值，取值为**0-100**，如：*Porn-SexBehavior 99* 则代表相应识别内容命中色情-性行为标签的分值为99。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Score: int
         """
@@ -395,6 +414,13 @@ class LabelDetailItem(AbstractModel):
         self.Id = params.get("Id")
         self.Name = params.get("Name")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class LabelResult(AbstractModel):
@@ -404,19 +430,17 @@ class LabelResult(AbstractModel):
 
     def __init__(self):
         """
-        :param Scene: 场景识别结果
+        :param Scene: 该字段用于返回模型识别出的场景结果，如广告、色情、有害内容等场景。
         :type Scene: str
-        :param Suggestion: 建议您拿到判断结果后的执行操作。
-建议值，Block：建议屏蔽，Review：建议复审，Pass：建议通过
+        :param Suggestion: 该字段用于返回针对当前恶意标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
         :type Suggestion: str
-        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义图片。
-以及其他令人反感、不安全或不适宜的内容类型。
+        :param Label: 该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
         :type Label: str
-        :param SubLabel: 子标签检测结果
+        :param SubLabel: 该字段用于返回对应恶意标签下的子标签的检测结果，如：*Porn-SexBehavior*等子标签。
         :type SubLabel: str
-        :param Score: 该标签模型命中的分值
+        :param Score: 该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容。
         :type Score: int
-        :param Details: 分类模型命中子标签结果
+        :param Details: 该字段用于返回分类模型命中子标签的详细信息，如：序号、命中标签名称、分数等信息。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Details: list of LabelDetailItem
         """
@@ -440,31 +464,37 @@ class LabelResult(AbstractModel):
                 obj = LabelDetailItem()
                 obj._deserialize(item)
                 self.Details.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class LibDetail(AbstractModel):
-    """自定义库/黑白库明细
+    """用于返回自定义库/黑白库的明细信息
 
     """
 
     def __init__(self):
         """
-        :param Id: 序号
+        :param Id: 该字段用于返回识别对象的ID以方便识别和区分。
         :type Id: int
-        :param LibId: 仅当Label为Custom自定义关键词时有效，表示自定义库id
+        :param LibId: 该字段**仅当Label为Custom：自定义关键词时该参数有效**,用于返回自定义库的ID，以方便自定义库管理和配置。
         :type LibId: str
-        :param LibName: 仅当Label为Custom自定义关键词时有效，表示自定义库名称
+        :param LibName: 该字段**仅当Label为Custom：自定义关键词时该参数有效**,用于返回自定义库的名称,以方便自定义库管理和配置。
 注意：此字段可能返回 null，表示取不到有效值。
         :type LibName: str
-        :param ImageId: 图片ID
+        :param ImageId: 该字段用于返回识别图像对象的ID以方便文件管理。
         :type ImageId: str
-        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义词库。
-以及其他其他令人反感、不安全或不适宜的内容类型。
+        :param Label: 该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
         :type Label: str
-        :param Tag: 自定义标签
+        :param Tag: 该字段用于返回其他自定义标签以满足您的定制化场景需求，若无需求则可略过。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Tag: str
-        :param Score: 命中的模型分值
+        :param Score: 该字段用于返回对应模型命中的分值，取值为**0-100**，如：*Porn 99* 则代表相应识别内容命中色情标签的分值为99。
         :type Score: int
         """
         self.Id = None
@@ -484,29 +514,34 @@ class LibDetail(AbstractModel):
         self.Label = params.get("Label")
         self.Tag = params.get("Tag")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class LibResult(AbstractModel):
-    """黑白库结果明细
+    """用于返回黑白库比对结果的详细信息
 
     """
 
     def __init__(self):
         """
-        :param Scene: 场景识别结果
+        :param Scene: 该字段表示模型的场景识别结果，默认取值为Similar。
         :type Scene: str
-        :param Suggestion: 建议您拿到判断结果后的执行操作。
-建议值，Block：建议屏蔽，Review：建议复审，Pass：建议通过
+        :param Suggestion: 该字段用于返回后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
         :type Suggestion: str
-        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义词库。
-以及其他令人反感、不安全或不适宜的内容类型。
+        :param Label: 该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
         :type Label: str
-        :param SubLabel: 子标签检测结果
+        :param SubLabel: 该字段用于返回恶意标签下对应的子标签的检测结果，如：*Porn-SexBehavior*等子标签。
 注意：此字段可能返回 null，表示取不到有效值。
         :type SubLabel: str
-        :param Score: 该标签模型命中的分值
+        :param Score: 该字段用于返回图片检索模型识别的分值，取值为**0-100**，表示该审核图片**与库中样本的相似分值**，得分越高，代表当前内容越有可能命中相似图库内的样本。
         :type Score: int
-        :param Details: 黑白库结果明细
+        :param Details: 该字段用于返回黑白库比对结果的详细信息，如：序号、库名称、恶意标签等信息；详细返回信息敬请参考对应数据结构（[LibDetail](https://cloud.tencent.com/document/product/1125/53274#LibDetail)）的描述文档
 注意：此字段可能返回 null，表示取不到有效值。
         :type Details: list of LibDetail
         """
@@ -530,6 +565,13 @@ class LibResult(AbstractModel):
                 obj = LibDetail()
                 obj._deserialize(item)
                 self.Details.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Location(AbstractModel):
@@ -539,15 +581,15 @@ class Location(AbstractModel):
 
     def __init__(self):
         """
-        :param X: 左上角横坐标
+        :param X: 该参数用于返回检测框**左上角位置的横坐标**（x）所在的像素位置，结合剩余参数可唯一确定检测框的大小和位置。
         :type X: float
-        :param Y: 左上角纵坐标
+        :param Y: 该参数用于返回检测框**左上角位置的纵坐标**（y）所在的像素位置，结合剩余参数可唯一确定检测框的大小和位置。
         :type Y: float
-        :param Width: 宽度
+        :param Width: 该参数用于返回**检测框的宽度**（由左上角出发在x轴向右延伸的长度），结合剩余参数可唯一确定检测框的大小和位置。
         :type Width: float
-        :param Height: 高度
+        :param Height: 该参数用于返回**检测框的高度**（由左上角出发在y轴向下延伸的长度），结合剩余参数可唯一确定检测框的大小和位置。
         :type Height: float
-        :param Rotate: 检测框的旋转角度
+        :param Rotate: 该参数用于返回**检测框的旋转角度**，该参数结合X和Y两个坐标参数可唯一确定检测框的具体位置；取值：**0-360**（**角度制**），方向为**逆时针旋转**。
         :type Rotate: float
         """
         self.X = None
@@ -563,6 +605,13 @@ class Location(AbstractModel):
         self.Width = params.get("Width")
         self.Height = params.get("Height")
         self.Rotate = params.get("Rotate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ObjectDetail(AbstractModel):
@@ -572,16 +621,15 @@ class ObjectDetail(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: 序号
+        :param Id: 该参数用于返回识别对象的ID以方便识别和区分。
         :type Id: int
-        :param Name: 标签名称
+        :param Name: 该参数用于返回命中的实体标签。
         :type Name: str
-        :param Value: 标签值，
-当标签为二维码时，表示URL地址，如Name为QrCode时，Value为"http//abc.com/aaa"
+        :param Value: 该参数用于返回对应实体标签所对应的值或内容。如：当标签为*二维码(QrCode)*时，该字段为识别出的二维码对应的URL地址。
         :type Value: str
-        :param Score: 分数
+        :param Score: 该参数用于返回对应实体标签命中的分值，取值为**0-100**，如：*QrCode 99* 则代表相应识别内容命中二维码场景标签的概率非常高。
         :type Score: int
-        :param Location: 检测框坐标
+        :param Location: 该字段用于返回实体检测框的坐标位置（左上角xy坐标、长宽、旋转角度）以方便快速定位实体的相关信息。
         :type Location: :class:`tencentcloud.ims.v20201229.models.Location`
         """
         self.Id = None
@@ -599,31 +647,37 @@ class ObjectDetail(AbstractModel):
         if params.get("Location") is not None:
             self.Location = Location()
             self.Location._deserialize(params.get("Location"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ObjectResult(AbstractModel):
-    """实体检测结果详情：实体、广告台标、二维码
+    """用于返回实体检测结果详情
 
     """
 
     def __init__(self):
         """
-        :param Scene: 场景识别结果
+        :param Scene: 该字段用于返回实体识别出的实体场景结果，如二维码、logo、图片OCR等场景。
         :type Scene: str
-        :param Suggestion: 建议您拿到判断结果后的执行操作。
-建议值，Block：建议屏蔽，Review：建议复审，Pass：建议通过
+        :param Suggestion: 该字段用于返回针对当前恶意标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
         :type Suggestion: str
-        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义图片。
-以及其他令人反感、不安全或不适宜的内容类型。
+        :param Label: 该字段用于返回检测结果所对应的恶意标签，表示模型推荐的审核结果，建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
         :type Label: str
-        :param SubLabel: 子标签检测结果
+        :param SubLabel: 该字段用于返回当前恶意标签下对应的子标签的检测结果，如：*Porn-SexBehavior* 等子标签。
         :type SubLabel: str
-        :param Score: 该标签模型命中的分值
+        :param Score: 该字段用于返回命中当前恶意标签下子标签的分值，取值为**0-100**，如：*Porn-SexBehavior 99* 则代表相应识别内容命中色情-性行为标签的分值为99。
         :type Score: int
-        :param Names: 实体名称
+        :param Names: 该标签用于返回所识别出的实体名称。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Names: list of str
-        :param Details: 实体检测结果明细
+        :param Details: 该标签用于返回所识别出实体的详细信息，如：序号、命中标签名称、位置坐标等信息，详细返回内容敬请参考相应数据结构（[ObjectDetail
+](https://cloud.tencent.com/document/api/1125/53274#ObjectDetail)）。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Details: list of ObjectDetail
         """
@@ -649,31 +703,36 @@ class ObjectResult(AbstractModel):
                 obj = ObjectDetail()
                 obj._deserialize(item)
                 self.Details.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OcrResult(AbstractModel):
-    """OCR结果检测详情
+    """用于返回OCR结果检测详情
 
     """
 
     def __init__(self):
         """
-        :param Scene: 场景识别结果
+        :param Scene: 该字段表示识别场景，取值默认为OCR（图片OCR识别）。
         :type Scene: str
-        :param Suggestion: 建议您拿到判断结果后的执行操作。
-建议值，Block：建议屏蔽，Review：建议复审，Pass：建议通过
+        :param Suggestion: 该字段用于返回优先级最高的恶意标签对应的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
         :type Suggestion: str
-        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义词库。
-以及其他令人反感、不安全或不适宜的内容类型。
+        :param Label: 该字段用于返回OCR检测结果所对应的优先级最高的恶意标签，表示模型推荐的审核结果，建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
         :type Label: str
-        :param SubLabel: 子标签检测结果
+        :param SubLabel: 该字段用于返回当前标签（Label）下对应的子标签的检测结果，如：*Porn-SexBehavior*等子标签。
         :type SubLabel: str
-        :param Score: 该标签模型命中的分值
+        :param Score: 该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容。
         :type Score: int
-        :param Details: ocr结果详情
+        :param Details: 该字段用于返回OCR识别出的结果的详细内容，如：文本内容、对应标签、识别框位置等信息。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Details: list of OcrTextDetail
-        :param Text: ocr识别出的文本结果
+        :param Text: 该字段用于返回OCR识别出的文字信息。
         :type Text: str
         """
         self.Scene = None
@@ -698,31 +757,37 @@ class OcrResult(AbstractModel):
                 obj._deserialize(item)
                 self.Details.append(obj)
         self.Text = params.get("Text")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class OcrTextDetail(AbstractModel):
-    """OCR文本结果详情
+    """用于返回OCR文本结果详情，图片中的文本越多，可能导致接口返回时间增加。
 
     """
 
     def __init__(self):
         """
-        :param Text: OCR文本内容
+        :param Text: 该字段用于返回OCR识别出的文本内容。<br>备注：OCR文本识别上限在**5000字节内**。
         :type Text: str
-        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义词库。
-以及其他令人反感、不安全或不适宜的内容类型。
+        :param Label: 该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
         :type Label: str
-        :param LibId: 仅当Label为Custom自定义关键词时有效，表示自定义库id
+        :param LibId: 该字段**仅当Label为Custom自定义关键词时有效**，用于返回自定义库的ID，以方便自定义库管理和配置。
         :type LibId: str
-        :param LibName: 仅当Label为Custom自定义关键词时有效，表示自定义库名称
+        :param LibName: 该字段**仅当Label为Custom自定义关键词时有效**，用于返回自定义库的名称，以方便自定义库管理和配置。
         :type LibName: str
-        :param Keywords: 该标签下命中的关键词
+        :param Keywords: 该参数用于返回在当前label下命中的关键词。
         :type Keywords: list of str
-        :param Score: 该标签模型命中的分值
+        :param Score: 该参数用于返回在当前恶意标签下模型命中的分值，取值为**0-100**；分数越高，代表当前场景越符合该恶意标签所对应的场景。
         :type Score: int
-        :param Location: OCR位置
+        :param Location: 该参数用于返回OCR检测框在图片中的位置（左上角xy坐标、长宽、旋转角度），以方便快速定位识别文字的相关信息。
         :type Location: :class:`tencentcloud.ims.v20201229.models.Location`
-        :param Rate: OCR文本识别置信度
+        :param Rate: 该参数用于返回OCR文本识别结果的置信度，取值在**0**（**置信度最低**）-**100**（**置信度最高**），越高代表对应图像越有可能是识别出的文字；如：*你好 99*，则表明OCR识别框内的文字大概率是”你好“。
         :type Rate: int
         """
         self.Text = None
@@ -746,37 +811,50 @@ class OcrTextDetail(AbstractModel):
             self.Location = Location()
             self.Location._deserialize(params.get("Location"))
         self.Rate = params.get("Rate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class User(AbstractModel):
-    """User结果
+    """用于表示业务用户的账号相关信息
 
     """
 
     def __init__(self):
         """
-        :param UserId: 业务用户ID 如填写，会根据账号历史恶意情况，判定消息有害结果，特别是有利于可疑恶意情况下的辅助判断。账号可以填写微信uin、QQ号、微信openid、QQopenid、字符串等。该字段和账号类别确定唯一账号。
+        :param UserId: 该字段表示业务用户ID,填写后，系统可根据账号过往违规历史优化审核结果判定，有利于存在可疑违规风险时的辅助判断。<br>
+备注：该字段可传入微信openid、QQopenid、字符串等账号信息，与账号类别参数（AccountType）配合使用可确定唯一账号。
         :type UserId: str
-        :param AccountType: 业务用户ID类型 "1-微信uin 2-QQ号 3-微信群uin 4-qq群号 5-微信openid 6-QQopenid 7-其它string"
-        :type AccountType: str
-        :param Nickname: 用户昵称
+        :param Nickname: 该字段表示业务用户对应的账号昵称信息。
         :type Nickname: str
-        :param Gender: 性别 默认0 未知 1 男性 2 女性
+        :param AccountType: 该字段表示业务用户ID对应的账号类型，取值：**1**-微信uin，**2**-QQ号，**3**-微信群uin，**4**-qq群号，**5**-微信openid，**6**-QQopenid，**7**-其它string。<br>
+该字段与账号ID参数（UserId）配合使用可确定唯一账号。
+        :type AccountType: str
+        :param Gender: 该字段表示业务用户对应账号的性别信息。<br>
+取值：**0**（默认值，代表性别未知）、**1**（男性）、**2**（女性）。
         :type Gender: int
-        :param Age: 年龄 默认0 未知
+        :param Age: 该字段表示业务用户对应账号的年龄信息。<br>
+取值：**0**（默认值，代表年龄未知）-（**自定义年龄上限**）之间的整数。
         :type Age: int
-        :param Level: 用户等级，默认0 未知 1 低 2 中 3 高
+        :param Level: 该字段表示业务用户对应账号的等级信息。<br>
+取值：**0**（默认值，代表等级未知）、**1**（等级较低）、**2**（等级中等）、**3**（等级较高），目前**暂不支持自定义等级**。
         :type Level: int
-        :param Phone: 手机号
+        :param Phone: 该字段表示业务用户对应账号的手机号信息，支持全球各地区手机号的记录。<br>
+备注：请保持手机号格式的统一，如区号格式（086/+86）等。
         :type Phone: str
-        :param Desc: 用户简介，长度不超过5000字
+        :param Desc: 该字段表示业务用户的简介信息，支持汉字、英文及特殊符号，**长度不超过5000个汉字字符**。
         :type Desc: str
-        :param HeadUrl: 用户头像图片链接
+        :param HeadUrl: 该字段表示业务用户头像图片的访问链接(URL)，支持PNG、JPG、JPEG、BMP、GIF、WEBP格式。<br>备注：头像图片**大小不超过5MB**，建议**分辨率不低于256x256**；图片下载时间限制为3秒，超过则会返回下载超时。
         :type HeadUrl: str
         """
         self.UserId = None
-        self.AccountType = None
         self.Nickname = None
+        self.AccountType = None
         self.Gender = None
         self.Age = None
         self.Level = None
@@ -787,11 +865,18 @@ class User(AbstractModel):
 
     def _deserialize(self, params):
         self.UserId = params.get("UserId")
-        self.AccountType = params.get("AccountType")
         self.Nickname = params.get("Nickname")
+        self.AccountType = params.get("AccountType")
         self.Gender = params.get("Gender")
         self.Age = params.get("Age")
         self.Level = params.get("Level")
         self.Phone = params.get("Phone")
         self.Desc = params.get("Desc")
-        self.HeadUrl = params.get("HeadUrl")
\ No newline at end of file
+        self.HeadUrl = params.get("HeadUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
